@@ -27,6 +27,10 @@ class Renderer:
             members = [self.render(member, node) for member in node.members]
         return self.render_node(node, docstring, members, parent)
 
+    def render_page(self, node, module: str, members: List[str]) -> str:
+        template = self.templates["page"]
+        return template.render(node=node, module=module, members=members)
+
     def render_node(self, node, docstring: str, members: List[str], parent) -> str:
         template = self.templates["node"]
         return template.render(
@@ -42,12 +46,11 @@ class Renderer:
                 section.html = self.render_section(section)
         return template.render(docstring=docstring)
 
-    def render_code(self, code: str) -> str:
-        template = self.templates["code"]
-        return template.render(code=code)
-
     def render_section(self, section) -> str:
         if section.name in ["Parameters", "Attributes", "Raises"]:
             return self.templates["args"].render(section=section)
         else:
             raise ValueError(f"Invalid section name: {section.name}")
+
+
+renderer = Renderer()
